===========
MozDef Util
===========


Utilities shared throughout the MozDef codebase


* Free software: Mozilla Public License 2.0
* Documentation: https://mozdef-util.readthedocs.io.


Features
--------

* TODO

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
